"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jetpack = require("fs-jetpack");
const src_1 = require("../src");
const pkgDir = require("pkg-dir");
test('Compiles & exports correctly', async () => {
    const dir = await pkgDir(__dirname);
    let requiredJS;
    expect(() => {
        requiredJS = require(dir);
    }).not.toThrow();
    expect(requiredJS.Umzug).toBeTruthy();
    expect(requiredJS.Migration).toBeTruthy();
    expect(requiredJS.migrationsList).toBeTruthy();
});
test('migrationsList() works', async () => {
    const executed = [];
    await jetpack.removeAsync('umzug.json');
    const umzug = new src_1.Umzug({
        migrations: src_1.migrationsList([
            {
                name: '00-first-migration',
                async up() {
                    executed.push('00-first-migration-up');
                },
                async down() {
                    executed.push('00-first-migration-down');
                },
            },
            {
                name: '01-second-migration',
                async up() {
                    executed.push('01-second-migration-up');
                },
                async down() {
                    executed.push('01-second-migration-down');
                },
            },
        ]),
    });
    const names = (migrations) => migrations.map(m => m.file);
    // Before anything
    expect(executed).toEqual([]);
    expect(names(await umzug.executed())).toEqual([]);
    expect(names(await umzug.pending())).toEqual(['00-first-migration', '01-second-migration']);
    // Up: all at once
    expect(names(await umzug.up())).toEqual(['00-first-migration', '01-second-migration']);
    expect(executed).toEqual(['00-first-migration-up', '01-second-migration-up']);
    expect(names(await umzug.executed())).toEqual(['00-first-migration', '01-second-migration']);
    expect(names(await umzug.pending())).toEqual([]);
    // Down: one by one
    expect(names(await umzug.down())).toEqual(['01-second-migration']);
    expect(executed).toEqual(['00-first-migration-up', '01-second-migration-up', '01-second-migration-down']);
    expect(names(await umzug.executed())).toEqual(['00-first-migration']);
    expect(names(await umzug.pending())).toEqual(['01-second-migration']);
    expect(names(await umzug.down())).toEqual(['00-first-migration']);
    expect(executed).toEqual([
        '00-first-migration-up',
        '01-second-migration-up',
        '01-second-migration-down',
        '00-first-migration-down',
    ]);
    expect(names(await umzug.executed())).toEqual([]);
    expect(names(await umzug.pending())).toEqual(['00-first-migration', '01-second-migration']);
    await jetpack.removeAsync('umzug.json');
});
test('migration sort', async () => {
    const executed = [];
    await jetpack.removeAsync('umzug.json');
    const umzug = new src_1.Umzug({
        migrations: src_1.migrationsList([
            {
                name: '00-first-migration',
                async up() {
                    executed.push('00-first-migration-up');
                },
                async down() {
                    executed.push('00-first-migration-down');
                },
            },
            {
                name: '01-second-migration',
                async up() {
                    executed.push('01-second-migration-up');
                },
                async down() {
                    executed.push('01-second-migration-down');
                },
            },
        ]),
        migrationSorting: (a, b) => {
            if (a > b) {
                return -1;
            }
            if (a < b) {
                return 1;
            }
            return 0;
        },
    });
    const names = (migrations) => migrations.map(m => m.file);
    // Before anything
    expect(executed).toEqual([]);
    expect(names(await umzug.executed())).toEqual([]);
    expect(names(await umzug.pending())).toEqual(['01-second-migration', '00-first-migration']);
    // Up: all at once
    expect(names(await umzug.up())).toEqual(['01-second-migration', '00-first-migration']);
    expect(executed).toEqual(['01-second-migration-up', '00-first-migration-up']);
    expect(names(await umzug.executed())).toEqual(['01-second-migration', '00-first-migration']);
    expect(names(await umzug.pending())).toEqual([]);
    // Down: one by one
    expect(names(await umzug.down())).toEqual(['00-first-migration']);
    expect(executed).toEqual(['01-second-migration-up', '00-first-migration-up', '00-first-migration-down']);
    expect(names(await umzug.executed())).toEqual(['01-second-migration']);
    expect(names(await umzug.pending())).toEqual(['00-first-migration']);
    expect(names(await umzug.down())).toEqual(['01-second-migration']);
    expect(executed).toEqual([
        '01-second-migration-up',
        '00-first-migration-up',
        '00-first-migration-down',
        '01-second-migration-down',
    ]);
    expect(names(await umzug.executed())).toEqual([]);
    expect(names(await umzug.pending())).toEqual(['01-second-migration', '00-first-migration']);
    await jetpack.removeAsync('umzug.json');
});
//# sourceMappingURL=test.js.map